function [tfr2,OrderedSurfaces]=tfrsurf(tfr,threshold,keep,ptrace);
// extract from a time-frequency representation the biggest energy dots
// Calling Sequence
//      [tfr2,OrderedSurfaces]=tfrsurf(tfr);
//      [tfr2,OrderedSurfaces]=tfrsurf(tfr,threshold);
//      [tfr2,OrderedSurfaces]=tfrsurf(tfr,threshold,keep);
//      [tfr2,OrderedSurfaces]=tfrsurf(tfr,threshold,keep,trace);
// Parameters
//        TFR       : time-frequency representation.
//        THRESHOLD : the energy threshold, in // 
//        KEEP      : number of dots to keep
//        TRACE     : if nonzero, the progression of the algorithm is shown     (default : 0).
// Examples
// N=256; 
// sig=fmlin(N,0.1,0.3)+fmlin(N,0.3,0.4)+2*fmlin(N,0.05,0.2).*amgauss(N,190,70);
// tfr=tfrwv(sig,1:N,128);
// [tfr2,OrderedSurfaces]=tfrsurf(tfr,5,3,1);
// scf(1);tfrview(tfr,sig,1:N,'tfrwv',[2 1 5 10 128 2 1 5],'plot')
// title('original tfr');
// scf(2);tfrview(tfr2,sig,1:N,'tfrwv',[2 1 5 10 128 2 1 5],'plot');
// title('modified tfr');
// scf(3);semilogy(1:10,OrderedSurfaces(1:10),'-',1:10,OrderedSurfaces(1:10),'o');
// title('number of points of the 10 biggest dots');
//	See also 
//        imextract.
//     Authors
//      H. Nahrstaedt - Aug 2010
//      F. Auger, oct 1999
//	Copyright (c) CNRS - France 1999. 

//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 [nargout,nargin]=argn(0);
if nargin==1, 
 threshold=5; keep=10; ptrace=0;
elseif nargin==2, 
 keep=10; ptrace=0;
elseif nargin==3, 
 ptrace=0; 
end;

[Nbrow,Nbcol]=size(tfr);
TheMax=max(tfr);
[EnergyDots,NbDots]=imextrac((tfr>=threshold*TheMax*0.01),ptrace);
Surfaces=zeros(1,NbDots+1);
for i=0:NbDots,
 Surfaces(i+1)=length(find(EnergyDots==i));
end;
[OrderedSurfaces,Indices]=mtlb_sort(Surfaces(2:NbDots+1));
OrderedSurfaces=fliplr(OrderedSurfaces);
Indices=fliplr(Indices);

Binary=zeros(Nbrow,Nbcol);
for i=1:keep,
 DotIndice=find(EnergyDots==Indices(i));
 Binary(DotIndice)=1;
end;

tfr2=tfr.*Binary;

endfunction



function y=fliplr(x)
y=x(:,$:-1:1);
endfunction

